+++
title = "Table column alignment"
tags = ["table"]
draft = false
+++

## Table with 3 rows {#table-with-3-rows}

| Right           | Left                 | No        | Center                        |
|----------------:|:---------------------|-----------|:-----------------------------:|
| Long Content To | Spread Out the Width | Alignment | Of the Table To See Alignment |
| Right           | Left                 | Marker    | Center                        |


## Table with 2 rows {#table-with-2-rows}

| Left | Default | Center | Right |
|:-----|---------|:------:|------:|
| 1    | 2       | 3      | 4     |


## Table with 1 row {#table-with-1-row}

_A table with just 1 row with alignment markers is as good as just
that row without the alignment markers. But hey, a test is a test._

|      |         |        |       |
|:-----|---------|:------:|------:|
| Left | Default | Center | Right |


## Table with 0 rows! {#table-with-0-rows}

_A table with zero rows, with just alignment markers, doesn't make
sense. But hey, a test is a test._


You should see **no** table exported above.
